@@ -220,6 +220,7 @@ SGC is enabled.  */
 
 #ifdef HAVE_MATH_H
 #include <math.h>
+#include <complex.h>
 #endif
 
 #undef WORDS_BIGENDIAN
@@ -278,4 +279,5 @@ SGC is enabled.  */
 #undef HAVE_SYS_SOCKIO_H
 #undef HAVE_MALLOC_MALLOC_H
 #undef HAVE_OBJC_MALLOC_H
-
+#undef INFINITY
+#undef NAN
