@@ -116,7 +116,7 @@ float object_to_float();
 double object_to_double();
 
 /*  error.c  */
-EXTER object sKerror,sKparse_error,sKreader_error;;
+EXTER object sKerror,sKparse_error,sKreader_error,sKprogram_error;
 EXTER object sKwrong_type_argument;
 EXTER object sKcontrol_error;
 EXTER object sKcatch;
@@ -148,8 +148,8 @@ object ifuncall(object,int,...);
 object ifuncall1();
 object ifuncall2();
 object ifuncall3();
-object fcalln1(object,...);
-#define fcalln ((object (*)())fcalln1)
+/* object fcalln1(); */
+/* #define fcalln ((object (*)())fcalln1) */
 object Ieval();
 object Imacro_expand1();
 
@@ -260,7 +260,7 @@ object cdddar();
 object cddddr();
 object nth();
 object nthcdr();
-object make_cons();
+object make_cons1();
 object list(fixnum,...);
 object listA(fixnum,...);
 object append();
@@ -358,6 +358,14 @@ EXTER object user_package;
 #ifdef ANSI_COMMON_LISP
 EXTER object common_lisp_package;
 #endif
+#if 0
+#ifdef HAVE_TK
+EXTER object tk_package;
+#endif
+#ifdef HAVE_JAPI_H
+EXTER object japi_package;
+#endif
+#endif
 EXTER object keyword_package;
 EXTER object system_package;
 EXTER object sLApackageA;
@@ -550,9 +558,9 @@ EXTER int string_sign, string_boundary;
 
 /*  symbol.d  */
 EXTER object string_register;
-EXTER object gensym_prefix;
+/* EXTER object gensym_prefix; */
 /* EXTER int gensym_counter; */
-EXTER object sLgensym_counter;
+/* EXTER object sLgensym_counter; */
 EXTER object gentemp_prefix;
 EXTER int gentemp_counter;
 EXTER object token;
@@ -600,7 +608,7 @@ EXTER object sSsetf_function;
 EXTER object sLcommon,sLnull,sLcons,sLlist,siLproper_list,sLsymbol,sLarray,sLvector,sLbit_vector,sLstring;
 EXTER object sLsequence,sLsimple_array,sLsimple_vector,sLsimple_bit_vector,sLsimple_string;
 EXTER object sLcompiled_function,sLpathname,sLcharacter,sLnumber,sLrational,sLfloat;
-EXTER object sLinteger,sLratio,sLshort_float,sLstandard_char,sLinterpreted_function;
+EXTER object sLinteger,sLratio,sLshort_float,sLstandard_char,siLinterpreted_function;
 
 EXTER object sLchar,sLnon_negative_char,sLnegative_char,sLsigned_char,sLunsigned_char;
 EXTER object sLshort,sLnon_negative_short,sLnegative_short,sLsigned_short,sLunsigned_short;
@@ -614,7 +622,7 @@ EXTER object sLseqind,sLrnkind;
 
 EXTER object sLcomplex;
 EXTER object sLsingle_float,sLpackage,sLbignum,sLrandom_state,sLdouble_float,sLstream,sLbit,sLreadtable;
-EXTER object sLlong_float,sLhash_table,sLstructure,sLboolean,sLfile_stream,sLinput_stream,sLoutput_stream;
+EXTER object sLlong_float,sLhash_table,sLstructure,sLboolean,sLfile_stream,sLinput_stream,sLoutput_stream,sLtype_error;
 
 #ifdef ANSI_COMMON_LISP
 /* new ansi types */
@@ -627,7 +635,7 @@ EXTER object sLparse_error,sLprint_not_readable,sLprogram_error,sLreader_error,s
 EXTER object sLsimple_base_string,sLsimple_condition,sLsimple_type_error,sLsimple_warning,sLstandard_class;
 EXTER object sLstandard_generic_function,sLstandard_method,sLstandard_object,sLstorage_condition;
 EXTER object sLstream_error,sLstring_stream,sLstructure_class,sLstyle_warning,sLsynonym_stream;
-EXTER object sLtwo_way_stream,sLtype_error,sLunbound_slot,sLunbound_variable,sLundefined_function,sLwarning;
+EXTER object sLtwo_way_stream,sLunbound_slot,sLunbound_variable,sLundefined_function,sLwarning;
 EXTER object sLmethod_combination,sLstructure_object,sLdynamic_extent;
 #endif
 
