@@ -210,7 +210,7 @@ add_page_to_freelist(char *p, struct typemanager *tm)
     are many arrays in a system to make the headers not writable,
     but just SGC_TOUCH the header each time you write to it.   this
     is what is done with t_structure */
-  if (t== (tm_of(t_array)->tm_type))
+ if (t== (tm_of(t_array)->tm_type) || t== (tm_of(t_vector)->tm_type)) /*FIXME, do the touch*/
    sgc_type_map[np] |= SGC_PERM_WRITABLE;
    
 #endif 
@@ -1043,7 +1043,7 @@ gcl_init_alloc(void) {
 	  sizeof(struct shortfloat_struct), 256 ,1,0);
   init_tm(t_longfloat, "LLONG-FLOAT",
 	  sizeof(struct longfloat_struct), 170 ,1,0);
-  init_tm(t_complex, "CCOMPLEX", sizeof(struct complex), 170 ,1,0);
+  init_tm(t_complex, "CCOMPLEX", sizeof(struct ocomplex), 170 ,1,0);
   init_tm(t_character,"#CHARACTER",sizeof(struct character), 256 ,1,0);
   init_tm(t_package, ":PACKAGE", sizeof(struct package), 2*PAGESIZE / sizeof(struct package),1,0);
   init_tm(t_hashtable, "hHASH-TABLE", sizeof(struct hashtable), 78,1,0 );
@@ -1242,10 +1242,11 @@ DEFUN_NEW("ALLOCATE-RELOCATABLE-PAGES",object,fSallocate_relocatable_pages,SI
   CHECK_ARG_RANGE(1,2);
   if (npages  <= 0)
     FEerror("Requires positive arg",0);
-  if ((nrbpage > npages && rb_pointer >= rb_start + PAGESIZE*npages - 2*RB_GETA)
-      || 2*npages > real_maxpage-page(heap_end)-new_holepage-real_maxpage/32)
-    FEerror("Can't set the limit for relocatable blocks to ~D.",
-	    1, make_fixnum(npages));
+  if (nrbpage > npages || 2*npages > real_maxpage-page(heap_end)-new_holepage-real_maxpage/32) {
+    RETURN1(make_fixnum(nrbpage));
+  }
+/*     FEerror("Can't set the limit for relocatable blocks to ~D.", */
+/* 	    1, make_fixnum(npages)); */
   rb_end += (npages-nrbpage)*PAGESIZE;
   nrbpage = npages;
   rb_limit = rb_end - 2*RB_GETA;
