@@ -432,7 +432,7 @@ gcl_main(int argc, char **argv, char **envp)
 
     CMPtemp = CMPtemp1 = CMPtemp2 = CMPtemp3 = OBJNULL;
 
-    parse_plt();
+/*     parse_plt(); */
     gcl_init_init();
 
     sLApackageA->s.s_dbind = user_package;
@@ -1127,6 +1127,10 @@ FFN(siLsave_system)(void) {
   DO_BEFORE_SAVE
 #endif	
     
+    sLAstandard_inputA->s.s_dbind=standard_io;
+    sLAstandard_outputA->s.s_dbind=standard_io;
+    sLAerror_outputA->s.s_dbind=standard_io;
+
     saving_system = TRUE;
   GBC(t_contiguous);
   
@@ -1232,6 +1236,14 @@ init_main(void) {
   ADD_FEATURE("CLX-LITTLE-ENDIAN");
 #endif
   
+#ifndef NOSWITCH
+  ADD_FEATURE("SWITCH");
+#endif
+
+#ifndef NOINTDIV
+  ADD_FEATURE("INTDIV");
+#endif
+
 #ifndef PECULIAR_MACHINE
 #define BIGM    (int)((((unsigned int)(-1))/2))	 
   { 
@@ -1277,6 +1289,9 @@ init_main(void) {
   ADD_FEATURE("TK-PRIMITIVES");
 #endif	 
 
+#ifdef STATIC_LINKING
+  ADD_FEATURE("STATIC");
+#endif	 
   make_special("*FEATURES*",features);}
   
   make_si_function("SAVE-SYSTEM", siLsave_system);
