@@ -224,7 +224,7 @@ work during bootstrapping.
   (let ((initargs ())
 	(methods ()))
     (labels ((duplicate-option (name)
-	     (specific-error :invalid-form "The option ~S appears more than once." name))
+	     (error 'program-error :format-control "The option ~S appears more than once." :format-arguments (list name)))
 	     (check-declaration (declaration-specifiers)
 	       (loop for specifier in declaration-specifiers
 		     when (and (consp specifier)
@@ -232,9 +232,8 @@ work during bootstrapping.
 				       '(special ftype function inline
 						 notinline declaration)
 				       :test #'eq)) do
-				       (specific-error :invalid-form
-						       "Declaration specifier ~S is not allowed"
-						       specifier)))
+				       (error 'program-error :format-control "Declaration specifier ~S is not allowed"
+					      :format-arguments (list specifier))))
 	     (initarg (key &optional (new nil new-supplied-p))
 		      (if new-supplied-p
 			  (setf (getf initargs key) new)
@@ -269,7 +268,7 @@ work during bootstrapping.
 	   (push `(defmethod ,function-specifier ,@(cdr option))
 		 methods))
 	  (t ;unsupported things must get a 'program-error
-	   (specific-error :invalid-form "Unsupported option ~S." option))))
+	   (error 'program-error :format-control "Unsupported option ~S." :format-arguments (list option)))))
       
       (let ((declarations (initarg :declarations)))
 	(when declarations (initarg :declarations `',declarations))))
@@ -941,7 +940,7 @@ work during bootstrapping.
 (defun get-key-arg-tail (keyword list)
   (loop for (key . tail) on list by #'cddr
 	when (null tail) do
-	  (specific-error :invalid-form "Odd number of keyword arguments in ~S" list)
+	  (error 'program-error :format-control "Odd number of keyword arguments in ~S" :format-arguments (list list))
 	when (eq key keyword)
 	  return tail))
 
@@ -1230,17 +1229,12 @@ work during bootstrapping.
 	   existing function-specifier all-keys)))
 
 (defun generic-clobbers-function (function-specifier)
-  (restart-case
-      (specific-error :invalid-form
-       "~S already names an ordinary function or a macro.~%~
+  (cerror "Discard the existing definition." 'program-error 
+	  :format-control
+	  "~S already names an ordinary function or a macro.~%~
 	If you want to replace it with a generic function, you should remove~%~
-        the existing definition beforehand.~%"
-       function-specifier)
-    (continue ()
-      :report (lambda (stream)
-		(format stream "Discard the existing definition of ~S."
-			function-specifier))
-      (fmakunbound function-specifier))))
+        the existing definition beforehand.~%" :format-arguments (list function-specifier))
+  (fmakunbound function-specifier))
 
 (defvar *sgf-wrapper* 
   (#+cmu17 boot-make-wrapper #-cmu17 make-wrapper
@@ -1374,9 +1368,9 @@ work during bootstrapping.
 			       (early-method-lambda-list method)
 			       (method-lambda-list method)))
     (flet ((lose (format-control &rest format-args)
-	     (specific-error :invalid-form
+	     (error 'program-error :format-control
 			     "Attempt to add the method ~S to the generic function ~S.~%~
-                   But ~?" method gf format-control format-args))
+                   But ~?" :format-arguments (list method gf format-control format-args)))
 	   (compare (x y)
 	     (if (> x y) "more" "fewer")))
       (let ((gf-nreq (arg-info-number-required arg-info))
@@ -2002,6 +1996,7 @@ work during bootstrapping.
 
 (defun parse-specialized-lambda-list (arglist &optional post-keyword)
   ;;(declare (values parameters lambda-list specializers required-parameters))
+  (check-type arglist list)
   (let ((arg (car arglist)))
     (cond ((null arglist) (values nil nil nil nil))
 	  ((eq arg '&aux)
@@ -2039,7 +2034,7 @@ work during bootstrapping.
 	       (parse-specialized-lambda-list (cdr arglist))
 	     (values (cons (if (listp arg) (car arg) arg) parameters)
 		     (cons (if (listp arg) (car arg) arg) lambda-list)
-		     (cons (if (listp arg) (cadr arg) t) specializers)
+		     (cons (if (and (listp arg) (listp (cdr arg))) (cadr arg) t) specializers)
 		     (cons (if (listp arg) (car arg) arg) required)))))))
 
 
@@ -2050,15 +2045,21 @@ work during bootstrapping.
 #-cmu ;; CMUCL Has a real symbol-macrolet
 (progn
 (defmacro symbol-macrolet (bindings &body body &environment env)
-  (let ((specs (mapcar #'(lambda (binding)
-			   (list (car binding)
-				 (variable-lexical-p (car binding) env)
-				 (cadr binding)))
+  (let ((specs (mapcar (lambda (binding)
+			 (when (or (si::specialp (car binding)) (constantp (car binding)))
+			   (error 'program-error));FIXME
+			 (list (car binding)
+			       (variable-lexical-p (car binding) env)
+			       (cadr binding)))
 		       bindings)))
-    (walk-form `(progn ,@body)
+    (do ((l body (cdr l)))
+	((or (atom (car l)) (not (eq (caar l) 'declare))))
+      (dolist (ll (cdar l))
+	(when (and (consp ll) (eq (car ll) 'special) (some (lambda (x) (assoc x bindings)) (cdr ll)))
+	  (error 'program-error))));FIXME
+    (walk-form `(let nil ,@body)
 	       env
-	       #'(lambda (f c e)
-		   (expand-symbol-macrolet-internal specs f c e)))))
+	       (lambda (f c e) (expand-symbol-macrolet-internal specs f c e)))))
 
 (defun expand-symbol-macrolet-internal (specs form context env)
   (let ((entry nil))
@@ -2069,7 +2070,7 @@ work during bootstrapping.
 	       (caddr entry)
 	       form))
 	  ((not (listp form)) form)
-	  ((member (car form) '(setq setf))
+	  ((member (car form) '(setq setf psetf));FIXME -- other setf forms?  or real symbol-macrolet
 	   ;; Have to be careful.  We must only convert the form to a SETF
 	   ;; form when we convert one of the 'logical' variables to a form
 	   ;; Otherwise we will get looping in implementations where setf
@@ -2084,7 +2085,7 @@ work during bootstrapping.
 				       (eq (cadr entry)
 					   (variable-lexical-p (car tail)
 							       env)))
-				  (progn (setq kind 'setf)
+				  (progn (setq kind (if (eq kind 'psetf) kind 'setf))
 					 (caddr entry))
 				  (car tail))
 			      (cadr tail)
@@ -2094,17 +2095,29 @@ work during bootstrapping.
 		 (walker::recons form kind new-tail)))))
 	  ((eq (car form) 'multiple-value-setq)
 	   (let* ((vars (cadr form))
-		  (gensyms (mapcar #'(lambda (i) (declare (ignore i)) (gensym))
-				   vars)))
-	     `(multiple-value-bind ,gensyms 
-		  ,(caddr form)
-		.,(reverse (mapcar #'(lambda (v g) `(setf ,v ,g))
-				   vars
-				   gensyms)))))
-	  (t form))))
-)
+		  (vars (mapcar (lambda (x) 
+				  (let ((y (assoc x specs)))
+				    (if (and y (eq (cadr y) (variable-lexical-p x env))) (walker::macroexpand-all (caddr y) env) x))) vars))
+		  (gensyms (mapcar (lambda (i) (declare (ignore i)) (gensym)) vars))
+		  (pls (mapcan 'cdr (copy-tree (remove-if-not 'consp vars))))
+		  (psyms (mapcar (lambda (x) (declare (ignore x)) (gensym)) pls))
+		  (ppsyms psyms)
+		  (vars (mapcar (lambda (x) (if (atom x) x (cons (car x) (mapcar (lambda (x) (declare (ignore x)) (pop ppsyms)) (cdr x))))) vars)))
+	     `(let* ,(mapcar 'list psyms pls)
+		(multiple-value-bind 
+		 ,gensyms 
+		 ,(caddr form)
+		 .,(reverse (mapcar (lambda (v g) `(setf ,v ,g)) vars gensyms))))))
+	  ((eq (car form) 'conditions::restart-case)
+	   (let* ((nf (cadr form))
+		  (nf (let ((y (assoc nf specs)))
+			(if (and y (eq (cadr y) (variable-lexical-p nf env))) (walker::macroexpand-all (caddr y) env) nf))))
+	     (if (eq nf (cadr form)) form
+	       `(,(car form) ,nf ,@(cddr form)))))
+	  (t form)))))
 
 (defmacro with-slots (slots instance &body body)
+  (declare (optimize (safety 2)))
   (let ((in (gensym)))
     `(let ((,in ,instance))
        (declare (ignorable ,in))
