@@ -78,9 +78,12 @@ gcl_init_system(object no_init)
   if (type_of(no_init)!=t_symbol)
     error("Supplied no_init is not of type symbol\n");
 
+  ar_check_init(gcl_listlib,no_init);
   ar_check_init(gcl_predlib,no_init);
-  ar_check_init(gcl_setf,no_init);
   ar_check_init(gcl_arraylib,no_init);
+  ar_check_init(gcl_seq,no_init);
+  ar_check_init(gcl_seqlib,no_init);
+  ar_check_init(gcl_setf,no_init);
   ar_check_init(gcl_assert,no_init);
   ar_check_init(gcl_defstruct,no_init);
   ar_check_init(gcl_describe,no_init);
@@ -95,13 +98,12 @@ gcl_init_system(object no_init)
   lsp_init("../mod/gcl_win32.lsp"); /* Needed for package declaration when compiling later. */
 #endif
 #endif  
-  ar_check_init(gcl_iolib,no_init);
-  ar_check_init(gcl_listlib,no_init);
   ar_check_init(gcl_mislib,no_init);
+  ar_check_init(gcl_iolib,no_init);
+  ar_check_init(gcl_bnum,no_init);
+  ar_check_init(gcl_mnum,no_init);
   ar_check_init(gcl_numlib,no_init);
   ar_check_init(gcl_packlib,no_init);
-  ar_check_init(gcl_seq,no_init);
-  ar_check_init(gcl_seqlib,no_init);
   ar_check_init(gcl_trace,no_init);
   ar_check_init(gcl_sloop,no_init);
   ar_check_init(gcl_serror,no_init);
@@ -137,23 +139,23 @@ gcl_init_system(object no_init)
   ar_check_init(gcl_cmpwt,no_init);
   ar_check_init(gcl_cmpmain,no_init);
 
-#ifdef HAVE_XGCL
-  lsp_init("../xgcl-2/sysdef.lisp");
-  ar_check_init(gcl_Xlib,no_init);
-  ar_check_init(gcl_Xutil,no_init);
-  ar_check_init(gcl_X,no_init);
-  ar_check_init(gcl_XAtom,no_init);
-  ar_check_init(gcl_defentry_events,no_init);
-  ar_check_init(gcl_Xstruct,no_init);
-  ar_check_init(gcl_XStruct_l_3,no_init);
-  ar_check_init(gcl_general,no_init);
-  ar_check_init(gcl_keysymdef,no_init);
-  ar_check_init(gcl_X10,no_init);
-  ar_check_init(gcl_Xinit,no_init);
-  ar_check_init(gcl_dwtrans,no_init);
-  ar_check_init(gcl_tohtml,no_init);
-  ar_check_init(gcl_index,no_init);
-#endif
+/* #ifdef HAVE_XGCL */
+/*   lsp_init("../xgcl-2/sysdef.lisp"); */
+/*   ar_check_init(gcl_Xlib,no_init); */
+/*   ar_check_init(gcl_Xutil,no_init); */
+/*   ar_check_init(gcl_X,no_init); */
+/*   ar_check_init(gcl_XAtom,no_init); */
+/*   ar_check_init(gcl_defentry_events,no_init); */
+/*   ar_check_init(gcl_Xstruct,no_init); */
+/*   ar_check_init(gcl_XStruct_l_3,no_init); */
+/*   ar_check_init(gcl_general,no_init); */
+/*   ar_check_init(gcl_keysymdef,no_init); */
+/*   ar_check_init(gcl_X10,no_init); */
+/*   ar_check_init(gcl_Xinit,no_init); */
+/*   ar_check_init(gcl_dwtrans,no_init); */
+/*   ar_check_init(gcl_tohtml,no_init); */
+/*   ar_check_init(gcl_index,no_init); */
+/* #endif */
     
 #include "recompile.h"
   
