@@ -81,6 +81,7 @@ gcl_init_system(object no_init)
     error("Supplied no_init is not of type symbol\n");
 
   lsp_init("../lsp/gcl_predlib.lsp");
+  lsp_init("../lsp/gcl_assert.lsp");
   lsp_init("../lsp/gcl_listlib.lsp");
   lsp_init("../lsp/gcl_mislib.lsp");
   lsp_init("../lsp/gcl_setf.lsp");
@@ -88,9 +89,9 @@ gcl_init_system(object no_init)
 
   lsp_init("../lsp/gcl_seq.lsp");
   lsp_init("../lsp/gcl_seqlib.lsp");
+  lsp_init("../lsp/gcl_bnum.lsp");
   lsp_init("../lsp/gcl_numlib.lsp");
 
-  lsp_init("../lsp/gcl_assert.lsp");
   lsp_init("../lsp/gcl_defstruct.lsp");
   lsp_init("../lsp/gcl_describe.lsp");
 #ifdef HAVE_JAPI_H
@@ -105,21 +106,11 @@ gcl_init_system(object no_init)
 #endif
 #endif  
   lsp_init("../lsp/gcl_iolib.lsp");
-/*   lsp_init("../lsp/gcl_listlib.lsp"); */
-/*   lsp_init("../lsp/gcl_mislib.lsp"); */
-/*   lsp_init("../lsp/gcl_numlib.lsp"); */
   lsp_init("../lsp/gcl_packlib.lsp");
-/*   lsp_init("../lsp/gcl_seq.lsp"); */
-/*   lsp_init("../lsp/gcl_seqlib.lsp"); */
   lsp_init("../lsp/gcl_trace.lsp");
   lsp_init("../lsp/gcl_sloop.lsp");
   lsp_init("../lsp/gcl_serror.lsp");
 
-/*   lsp_init("../mod/gcl_destructuring_bind.lsp"); */
-/*   lsp_init("../mod/gcl_loop.lsp"); */
-/*   lsp_init("../mod/gcl_defpackage.lsp"); */
-/*   lsp_init("../mod/gcl_make_defpackage.lsp"); */
-
   lsp_init("../cmpnew/gcl_cmptype.lsp");
   lsp_init("../cmpnew/gcl_cmpinline.lsp");
   lsp_init("../cmpnew/gcl_cmputil.lsp");
@@ -127,7 +118,6 @@ gcl_init_system(object no_init)
   lsp_init("../lsp/gcl_debug.lsp");
   lsp_init("../lsp/gcl_info.lsp");
 
-/*   lsp_init("../cmpnew/gcl_cmptype.lsp"); */
   lsp_init("../cmpnew/gcl_cmpbind.lsp");
   lsp_init("../cmpnew/gcl_cmpblock.lsp");
   lsp_init("../cmpnew/gcl_cmpcall.lsp");
